#
# spec file for package DisplayCAL (SUSE based distributions only)
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Florian Hoech
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define numpy_version 1.0
%define py_minversion 2.6
%define py_maxversion 2.7
%define wx_minversion 3.0

%global debug_package %{nil}

Summary:        Display calibration and profiling with a focus on accuracy and versatility
License:        GPL-3.0+
Group:          Productivity/Graphics/Other
Name:           DisplayCAL
Version:        3.5.3.0
Release:        lp151.3.3.1
Source0:        http://displaycal.net/download/%{name}-%version.tar.gz
Url:            https://displaycal.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       p7zip
Obsoletes:      DisplayCAL-0install
Provides:       dispcalGUI = %{version}
Obsoletes:      dispcalGUI < 3.1.0.0
Obsoletes:      dispcalGUI-0install < 3.1.0.0
BuildRequires:  gcc
BuildRequires:  python-devel
BuildRequires:  udev
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86vm)
Requires:       argyllcms
Requires:       python-xml
Requires:       python-numpy >= %{numpy_version}
Requires:       libSDL2_mixer-2_0-0
Requires:       python-wxGTK >= %{wx_minversion}
%py_requires

%description
This utility calibrates and characterizes display devices using one
of many supported measurement instruments, with support for
multi-display setups and a variety of available options for advanced
users, such as verification and reporting functionality to evaluate
ICC profiles and display devices, creating video 3D LUTs, as well as
optional CIECAM02 gamut mapping to take into account varying viewing
conditions.

%prep
%setup
# Convert line endings in LICENSE.txt
%{__python} -c "f = open('LICENSE.txt', 'rb')
d = f.read().replace('\r\n', '\n').replace('\r', '\n')
f.close()
f = open('LICENSE.txt', 'wb')
f.write(d)
f.close()"

%build
%{__python} setup.py build --use-distutils

%install
install_lib=`%{__python} -c "from distutils.sysconfig import get_python_lib;print get_python_lib(True)"`
%{__python} setup.py install --use-distutils \
	--root=$RPM_BUILD_ROOT \
	--prefix=%_prefix \
	--exec-prefix=%_exec_prefix \
	--install-data=%_datadir \
    --install-lib=${install_lib} \
	--skip-instrument-configuration-files \
	--skip-postinstall \
	--record=INSTALLED_FILES

# Strip extensions
bits=`%{__python} -c "import platform;print platform.architecture()[0][:2]"`
python_shortversion=`%{__python} -c "import sys;print ''.join(map(str, sys.version_info[:2]))"`
strip --strip-unneeded ${RPM_BUILD_ROOT}${install_lib}/%{name}/lib${bits}/python${python_shortversion}/*.so

# Remove doc directory
if [ -e "${RPM_BUILD_ROOT}%_datadir/doc/%{name}-%{version}" ]; then
	rm -rf "${RPM_BUILD_ROOT}%_datadir/doc/%{name}-%{version}"
fi

# Update desktop files to prevent buildservice from complaining
desktopfilenames=`%{__python} -c "import glob
import os
print ' '.join([os.path.splitext(os.path.basename(path))[0] for path in
				glob.glob('misc/displaycal*.desktop')])"`
for desktopfilename in $desktopfilenames ; do
	%suse_update_desktop_file $desktopfilename 2DGraphics
done
%suse_update_desktop_file "%{buildroot}/etc/xdg/autostart/z-displaycal-apply-profiles.desktop"

# Prepare files list:
# - Remove traces of RPM_BUILD_ROOT
# - Remove unused files from list of installed files and add directories
#   as well as mark files as executable where needed
%{__python} -c "import os
f = open('INSTALLED_FILES')
paths = [chr(0x22) + path.replace('$RPM_BUILD_ROOT', '').strip() + chr(0x22) for path in 
		 filter(lambda path: not '/doc/' in path and not '/etc/' in path and
				not '/man/' in path, 
				f.readlines())]
f.close()
executables = ['Argyll'] + os.listdir('scripts')
for path in list(paths):
	path = path.strip(chr(0x22))
	if os.path.basename(path) in executables:
		paths.remove(chr(0x22) + path + chr(0x22))
		paths.append('%attr(755, root, root) ' + chr(0x22) + path + chr(0x22))
	while True:
		path = os.path.dirname(path)
		if os.path.isdir(path):
			break
		else:
			directory = '%dir ' + chr(0x22) + path + chr(0x22)
			if not directory in paths:
				paths.append(directory)
f = open('INSTALLED_FILES', 'w')
f.write('\n'.join(paths))
f.close()"

%files -f INSTALLED_FILES
%defattr(-,root,root)
%config /etc/xdg/autostart/z-displaycal-apply-profiles.desktop
%doc LICENSE.txt
%doc README.html
%doc README-fr.html
%doc screenshots
%doc theme
/usr/share/man/man1/*

%post
#!/bin/sh

# Update icon cache and menu
/bin/touch --no-create %{_datadir}/icons/hicolor &> /dev/null || true
which xdg-icon-resource &> /dev/null && xdg-icon-resource forceupdate || true
which xdg-desktop-menu &> /dev/null && xdg-desktop-menu forceupdate || true

%postun
#!/bin/sh

# Update icon cache and menu
/bin/touch --no-create %{_datadir}/icons/hicolor &> /dev/null || true
which xdg-desktop-menu &> /dev/null && xdg-desktop-menu forceupdate || true
which xdg-icon-resource &> /dev/null && xdg-icon-resource forceupdate || true

%changelog
* Mon Jan 13 2020 Martin Wilck <mwilck@suse.com>
- Added dependency on python-xml. Without it, DisplayCAL won't
  start (fixed in factory already).
* Wed Apr 25 2018 obs-packaging@displaycal.net
- Update to 3.5.3:
  * [Feature] Rudimentary ICCv4 profile autoconversion support
    (only matrix profile types)
  * [Enhancement] Lookup table based test profiles for evaluating
    display color management
  * [Enhancement] Profile information: Ability to plot CMYK profile
    tone response curves
  * [Enhancement] HDR SMPTE 2084 roll-off 3D LUT: Improved tone
    mapping
  * [Enhancement] Slightly improved accuracy of XYZ LUT profile
    CIECAM02 gamut mapping
  * Temporarily restored compatibility with wxPython 2.8.11/12
  * [Minor] Restored ability to create profiles from non RGB device
    measurement files
  * [Minor] Profile information: Deal with potential NULL values in
    meta tags of 3rd party ICC profiles
  * [Trivial] Profile information: Correctly parse non-default
    device media type attributes
  * [Trivial] Profile information: Keep original tag order of 3rd
    party profiles when checking ID
  * [Trivial] Fix AppData XML
* Sun Apr  1 2018 mrueckert@suse.de
- Update to 3.5.2.0:
  - TRIVIAL Prevent potential “service/proto not found” error due
    to unreliable system APIs when attempting to automatically
    download updates or vendor files.
  - TRIVIAL Linux: Restore missing icons in the window switcher and
    panel under XFCE.
  - TRIVIAL Linux: Add missing i1 Studio entry to bundled
    instrument configuration files (ArgyllCMS >= 2.0).
  - TRIVIAL Windows: Use bundled certificate authority (CA)
    certificates to circumvent potentially outdated system
    certificates under older versions of Windows.
* Fri Mar 23 2018 mrueckert@suse.de
- Update to 3.5.1.0:
  - Added in this release:
  - FEATURE Rudimentary support for WCS Color Device Model
    profiles (only description, author, white- & blackpoint,
    gamma, parametric curve, and matrix tags are recognized and
    mapped to appropriate ICCv2 types).
  - Changed in this release:
  - UI Updated traditional chinese localization (thanks to
    楊添明).
  - ENHANCEMENT Update bundled vendor PNP ID database.
  - ENHANCEMENT Linux: Use SDL (Simple DirectMedia Layer)
    directly.
  - Fixed in this release:
  - MINOR Work around Python issue #738361 (shell pattern
    compilation fails raising an unhandled exception if a path
    contains certain combinations of meta characters).
  - MINOR Measurement report: Deal with quantization when
    creating the report (fixes error when using video output
    levels in combination with some display profiles).
  - MINOR Profile loader (Windows): Display a proper error
    message when associating an invalid profile.
  - MINOR Profile loader (Windows): In case of an invalid profile
    (e.g. damaged file), fall back to linear gamma ramps instead
    of using the previously cached ramps and change the tray icon
    to reflect this.
  - MINOR Profile loader (Windows): Ignore potential stray
    WM_COMMAND messages caused by 3rd party application
    interference.
  - MINOR Bump minimum required wxPython version to 3.0 (fixes a
    compatibility problem under Linux if wxPython 2.8 was
    installed).
  - COSMETIC Refresh output levels control when loading settings.
* Sun Feb 18 2018 obs@hoech.net
- Update to 3.5.0.0:
  * Maintenance/bugfixes
  * New application icons and slightly refreshed theme
  * See README.html#changelog-3.5
* Sat Dec 30 2017 obs@hoech.net
- Update to 3.4.0.0:
  * Critical: Prevent bad clipping in case of non-monotonic device
    response
  * Fix consistency of device to profile mapping accross external
    APIs (this fix is required to match how ArgyllCMS 2.0
    enumerates displays)
  * HDR improvements
  * Added simplified chinese translation
  * See README.html#changelog-3.4
* Tue Dec  5 2017 crrodriguez@opensuse.org
- Replace xorg-x11-devel build requires by the needed individual
  libraries.
  Wed Oct 18 17:36:43 UTC 2017 - florian_at_displaycal.net
- Update to 3.3.5.0:
  * Maintenance/bugfixes
  * Minor enhancements
  * Updated french localization
  * See README.html#changelog-3.3.5
  Wed Sep 13 12:10:59 UTC 2017 - florian_at_displaycal.net
- Update to 3.3.4.1:
  * Fix XRandR fallback not returning device ID in some cases
  * Fix visual whitepoint editor madTPG_Net interface
  * See README.html#changelog-3.3.4.1
* Tue Jun 13 2017 jengelh@inai.de
- Fix nonsensical 3.3 changelog entry.
  Revert description back to using 3rd singular form.
  Sun Jun 04 16:10:37 UTC 2017 - florian_at_displaycal.net
- Update to 3.3.1.0:
  * Fix unhandled exception when using CIECAM02 with alternate
    forward profiler
  * See README.html#changelog-3.3.1
  Thu Jun 01 16:11:48 UTC 2017 - florian_at_displaycal.net
- Update to 3.3.0.0:
  * Better multi CPU/multi core support. Generating high
    resolution PCS-to-device tables is now taking more advantage
    of multiple (physical or logical) processors (typical 2x
    speedup on a i7-6700K CPU).
  * Generating a simple high resolution perceptual table is now
    done by copying the colorimetric table and only generating
    new input curves. This markedly reduces the processing time
    needed to create the perceptual table (6x speedup on a
    i7-6700K CPU).
  * See README.html#changelog-3.3
  Sun Feb 19 16:46:26 UTC 2017 - florian_at_displaycal.net
- Update to 3.2.4.0:
  * Maintenance/bugfix release
  * See README.html#changelog-3.2.4
  Wed Jan 04 14:12:01 UTC 2017 - florian_at_displaycal.net
- Update to 3.2.3.0:
  * Maintenance/bugfix release
  * See README.html#changelog-3.2.3
  Tue Dec 13 22:29:24 UTC 2016 - florian_at_displaycal.net
- Update to 3.2.2.0:
  * Maintenance/bugfix release
  * See README.html#changelog-3.2.2
  Fri Nov 25 14:05:19 UTC 2016 - florian_at_displaycal.net
- update to 3.2.1.0: see README.html#changelog-3.2.1
  Sat Nov 19 11:04:10 UTC 2016 - florian_at_displaycal.net
- update to 3.2.0.0: see README.html#changelog-3.2
  Mon Oct 24 10:29:45 UTC 2016 - florian_at_displaycal.net
- update to 3.1.7.3: see README.html#changelog-3.1.7.3
  Tue Oct 04 20:50:59 UTC 2016 - florian_at_displaycal.net
- update to 3.1.7.0: see README.html#changelog-3.1.7
  Wed Aug 24 21:06:27 UTC 2016 - florian_at_displaycal.net
- update to 3.1.6.0: see README.html#changelog-3.1.6
  Tue Aug 02 21:20:48 UTC 2016 - florian_at_displaycal.net
- update to 3.1.5.0: see README.html#changelog-3.1.5
  Sun Jul 10 21:51:48 UTC 2016 - florian_at_displaycal.net
- update to 3.1.4.0: see README.html#changelog-3.1.4
  Mon Apr 11 08:53:40 UTC 2016 - florian_at_displaycal.net
- update to 3.1.3.1: see README.html#changelog-3.1.3.1
  Sat Apr 09 10:20:55 UTC 2016 - florian_at_displaycal.net
- update to 3.1.3.0: see README.html#changelog-3.1.3
* Wed Mar  9 2016 kkaempf@suse.com
- Add provides/obsoletes for the rename dispcalGUI -> DisplayCAL
  at version 3.1.0.0
  Mon Feb 29 16:43:24 UTC 2016 - florian_at_displaycal.net
- update to 3.1.1.0: see README.html#changelog-3.1.1
  Sun Jan 31 23:47:53 UTC 2016 - florian_at_displaycal.net
- update to 3.1.0.0:
  * renamed dispcalGUI to DisplayCAL
  * see README.html#changelog-3.1
  Mon Jan 11 10:34:55 UTC 2016 - dispcalGUI_at_hoech.net
- update to 3.0.6.3: see README.html#changelog-3.0.6.3
  Mon Dec 21 20:22:55 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.6.0: see README.html#changelog-3.0.6
  Thu Nov 26 22:06:42 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.5.0: see README.html#changelog-3.0.5
  Fri Sep 25 20:32:07 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.4.3: see README.html#changelog-3.0.4.3
  Mon Sep 07 13:06:27 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.4.2: see README.html#changelog-3.0.4.2
  Tue Sep 01 11:02:08 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.4.1: see README.html#changelog-3.0.4.1
  Sun Aug 09 23:23:27 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.4.0: see README.html#changelog-3.0.4
  Thu Jul 09 13:02:03 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.3.1: see README.html#changelog-3.0.3.1
  Mon Jul 06 21:01:35 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.3.0: see README.html#changelog-3.0.3
  Sun Jun 07 22:30:09 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.2.0: see README.html#changelog-3.0.2
  Sun May 31 18:43:10 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.1.0: see README.html#changelog-3.0.1
  Sat May 02 21:33:48 UTC 2015 - dispcalGUI_at_hoech.net
- update to 3.0.0.0: see README.html#changelog-3.0
  Sat Nov 15 19:47:26 UTC 2014 - dispcalGUI_at_hoech.net
- update to 2.6.0.0: see README.html#changelog-2.6
  Sat Sep 06 12:40:31 UTC 2014 - dispcalGUI_at_hoech.net
- update to 2.5.0.0: see README.html#changelog-2.5
  Sun May 11 17:06:37 UTC 2014 - dispcalGUI_at_hoech.net
- update to 2.1.0.0: see README.html#changelog-2.1
  Wed Apr 23 02:32:45 UTC 2014 - dispcalGUI_at_hoech.net
- update to 2.0.0.0: see README.html#changelog-2.0
  Sun Feb 09 22:34:19 UTC 2014 - dispcalGUI_at_hoech.net
- update to 1.7.5.7: see README.html#changelog-1.7.5.7
  Sun Jan 19 09:09:16 UTC 2014 - dispcalGUI_at_hoech.net
- update to 1.7.1.6: see README.html#changelog-1.7.1.6
  Wed Oct 23 20:09:44 UTC 2013 - dispcalGUI_at_hoech.net
- update to 1.5.3.1: see README.html#changelog-1.5.3.1
  Tue Oct 22 14:32:41 UTC 2013 - dispcalGUI_at_hoech.net
- update to 1.5.2.5: see README.html#changelog-1.5.2.5
  Sun Mar 03 19:22:01 UTC 2013 - dispcalGUI_at_oech.net
- update to 1.2.7.0: see README.html#changelog-1.2.7.0
  Fri Mar 01 16:47:49 UTC 2013 - dispcalGUI_at_hoech.net
- update to 1.2.6.6: see README.html#changelog-1.2.6.6
  Mon Jan 07 22:45:00 UTC 2013 - dispcalGUI_at_hoech.net
- Fix typo
  Mon Jan 07 21:49:00 UTC 2013 - dispcalGUI_at_hoech.net
- Fix missing man pages and made scripts executable
  Mon Jan 07 18:42:03 UTC 2013 - dispcalGUI_at_hoech.net
- update to 1.1.8.3: see README.html#changelog-1.1.8.3
  Sat Jan 05 12:40:52 UTC 2013 - dispcalGUI_at_hoech.net
- update to 1.1.7.0: see README.html#changelog-1.1.7.0
  Mon Nov 05 19:40:46 UTC 2012 - dispcalGUI_at_hoech.net
- update to 1.1.2.9: see README.html#changelog-1.1.2.9
  Fri Oct 05 17:05:00 UTC 2012 - dispcalGUI_at_hoech.net
- update to 1.1.2.1: see README.html#changelog-1.1.2.1
  Sat Sep 15 13:54:02 UTC 2012 - dispcalGUI_at_hoech.net
- update to 1.1.0.0: see README.html#changelog-1.1.0.0
  Wed Aug 01 09:08:34 UTC 2012 - dispcalGUI_at_hoech.net
- update to 1.0.9.0: see README.html#changelog-1.0.9.0
  Thu Jun 28 20:14:14 UTC 2012 - dispcalGUI_at_hoech.net
- update to 1.0.7.7: see README.html#changelog-1.0.7.7
  Fri Jun 22 22:26:46 UTC 2012 - dispcalGUI_at_hoech.net
- update to 1.0.7.6: see README.html#changelog-1.0.7.6
  Mon Jun 18 19:13:00 UTC 2012 - dispcalGUI_at_hoech.net
- define RPM group per-distro as before format_spec_file
  Sat Jun  9 12:47:00 UTC 2012 - dispcalGUI_at_hoech.net
- removed all udev stuff as it should already be handled by the
  Argyll dependency
* Thu May 10 2012 coolo@suse.com
- ran format_spec_file service to give the spec file a valid
  license (it already had a copyright)
* Wed May  2 2012 cfarrell@suse.com
- license update: GPL-3.0+
  Use SPDX syntax and always specify the version of the GPL that applies
  Thu Apr  5 17:19:55 UTC 2012 - dispcalGUI_at_hoech.net
- added .changes file
